##############################################################################
#
# Zope Public License (ZPL) Version 1.0
# -------------------------------------
#
# Copyright (c) Digital Creations.  All rights reserved.
#
# This license has been certified as Open Source(tm).
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
#
# 1. Redistributions in source code must retain the above copyright
#    notice, this list of conditions, and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions, and the following disclaimer in
#    the documentation and/or other materials provided with the
#    distribution.
#
# 3. Digital Creations requests that attribution be given to Zope
#    in any manner possible. Zope includes a "Powered by Zope"
#    button that is installed by default. While it is not a license
#    violation to remove this button, it is requested that the
#    attribution remain. A significant investment has been put
#    into Zope, and this effort will continue if the Zope community
#    continues to grow. This is one way to assure that growth.
#
# 4. All advertising materials and documentation mentioning
#    features derived from or use of this software must display
#    the following acknowledgement:
#
#      "This product includes software developed by Digital Creations
#      for use in the Z Object Publishing Environment
#      (http://www.zope.org/)."
#
#    In the event that the product being advertised includes an
#    intact Zope distribution (with copyright and license included)
#    then this clause is waived.
#
# 5. Names associated with Zope or Digital Creations must not be used to
#    endorse or promote products derived from this software without
#    prior written permission from Digital Creations.
#
# 6. Modified redistributions of any form whatsoever must retain
#    the following acknowledgment:
#
#      "This product includes software developed by Digital Creations
#      for use in the Z Object Publishing Environment
#      (http://www.zope.org/)."
#
#    Intact (re-)distributions of any official Zope release do not
#    require an external acknowledgement.
#
# 7. Modifications are encouraged but must be packaged separately as
#    patches to official Zope releases.  Distributions that do not
#    clearly separate the patches from the original work must be clearly
#    labeled as unofficial distributions.  Modifications which do not
#    carry the name Zope may be packaged in any form, as long as they
#    conform to all of the clauses above.
#
#
# Disclaimer
#
#   THIS SOFTWARE IS PROVIDED BY DIGITAL CREATIONS ``AS IS'' AND ANY
#   EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
#   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
#   PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL DIGITAL CREATIONS OR ITS
#   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
#   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
#   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
#   ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
#   OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
#   OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
#   SUCH DAMAGE.
#
#
# This software consists of contributions made by Digital Creations and
# many individuals on behalf of Digital Creations.  Specific
# attributions are listed in the accompanying credits file.
#
##############################################################################
from string import lower

from Products.CMFPropertyCore.PropertyContent import PropertyContent, beforeCreate, afterCreate

# Import permission names
import MailPermissions

#######################################
# text_filter

# If one forgots to disable (or replace) standard text_filter and they
# do not have pyperl or perl Jcode installed, then assume no
# filtering.
try:
    if 1: # disable or enable standard text_filter
        import perl
        perl.eval("use Jcode")

        def text_filter(input):
            if type(input) != type(''):
                return input
            elif input == '':
                return input

            # create text_filter_obj
            perl.eval("use Jcode")
            text_filter_obj = perl.callm("new","Jcode")
        
            return text_filter_obj.set(input).euc()
    else:
        def text_filter(input):
            return input
except:
    def text_filter(input):
        return input

#######################################
# extend_properties

# MailMessage
def extend_propertiesMailMessage(self,**kw):
    self._properties = self._extend_properties((
        # mailing list
        {'id':'subject',                  'type': 'lines',  'mode':'w'},
        # mail message
        {'id':'to',                       'type': 'string', 'mode':'w'},
        {'id':'title',                    'type': 'string', 'mode':'w'},
        {'id':'sender',                   'type': 'string', 'mode':'w'},
        {'id':'cc',                       'type': 'string', 'mode':'w'},
        {'id':'in_reply_to',              'type': 'string', 'mode':'w'},
        {'id':'message_id',               'type': 'string', 'mode':'w'},
        {'id':'date',                     'type': 'date',   'mode':'w'},
        # headers
        {'id':'headers',                  'type': 'string', 'mode':'w'},
        # body
        {'id':'body',                     'type': 'text',   'mode':'w'},
        ))
    self.manage_changeProperties(subject=text_filter(kw.get('subject',''))
                                 , to=text_filter(kw.get('to',None))
                                 , title=text_filter(kw.get('title',None))
                                 , sender=text_filter(kw.get('sender',None))
                                 , cc=text_filter(kw.get('cc',None))
                                 , in_reply_to=text_filter(kw.get('in_reply_to',None))
                                 , message_id=text_filter(kw.get('message_id',None))
                                 , date=text_filter(kw.get('date',None))
                                 , headers=kw.get('headers',None)
                                 , body=text_filter(kw.get('body',None))
                                 )

#######################################
# manage_Add

# MailMessage
def manage_addMailMessage(self,id=None,title=None,parent=None,REQUEST=None,**kw):
    """
    Create a mail message.
    """
    id = beforeCreate(id, 'mail', REQUEST)
    obj = PropertyContent(id, title, parent)
    # required due to duplicate key names
    kw['title'] = title
    apply(extend_propertiesMailMessage,(obj,),kw)
    afterCreate(self, id, obj, REQUEST)
    return id

#######################################
# factory_type_information

# template
factory_type_information_template = (
    { 'id'                : 'Mail'
      , 'meta_type'       : 'CMF Mail'
      , 'description'     : """\
Mail content object."""
      , 'icon'            : 'pcore_object_icon.gif'
      , 'product'         : 'CMFMail'
      , 'factory'         : 'manage_addMail'
      , 'immediate_view'  : 'mailmessage_view'
      , 'actions'         :
      ( { 'name'          : 'View'
          , 'action'      : 'mailmessage_view'
          , 'permissions' : (MailPermissions.View,)
          }
      , { 'name'          : 'Edit'
          , 'action'      : 'pcore_edit_form'
          , 'permissions' : (MailPermissions.Modify,)
          }
      , { 'name'          : 'Metadata'
          , 'action'      : 'metadata_edit_form'
          , 'permissions' : (MailPermissions.Modify,)
          }
        )
      }
    ,)

factory_type_information = []
for i in ('MailMessage',):
    import copy
    ft = copy.deepcopy(factory_type_information_template)
    ft[0].update({
        'id'            : i
        , 'meta_type'   : 'CMF %s' % i
        , 'description' : '%s object.' % i
        , 'icon'        : '%s_icon.png' % lower(i)
        , 'factory'     : 'manage_add%s' % i
        })
    factory_type_information.extend(ft)

factory_type_information = tuple(factory_type_information)
